Module dotenvy Copy item path Source Iter Error dotenv Loads the .env file from the current directory or parents. This is typically what you want. dotenv_iter Returns an iterator over environment variables. dotenv_override Loads all variables found in the reader into the environment,
overriding any existing environment variables of the same name. from_filename Loads environment variables from the specified file. from_filename_iter Returns an iterator over environment variables from the specified file. from_filename_override Loads environment variables from the specified file,
overriding existing environment variables. from_path Loads environment variables from the specified path. from_path_iter Returns an iterator over environment variables from the specified path. from_path_override Loads environment variables from the specified path,
overriding existing environment variables. from_read Loads environment variables from io::Read . from_read_iter Returns an iterator over environment variables from io::Read . from_read_override Loads environment variables from io::Read ,
overriding existing environment variables. var Gets the value for an environment variable. vars Returns an iterator of (key, value) pairs for all environment variables of the current process.
The returned iterator contains a snapshot of the process’s environment variables at the time of invocation. Modifications to environment variables afterwards will not be reflected. Result